package com.ruoyi.project.plant.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.plant.domain.TMtEhsopenitem;

/**
 * EHS开项跟踪Mapper接口
 *
 * @author ruoyi
 * @date 2021-01-04
 */
public interface TMtEhsopenitemMapper
{
    /**
     * 查询EHS开项跟踪
     *
     * @param id EHS开项跟踪ID
     * @return EHS开项跟踪
     */
    public TMtEhsopenitem selectTMtEhsopenitemById(Long id);

    /**
     * 查询EHS开项跟踪列表
     *
     * @param tMtEhsopenitem EHS开项跟踪
     * @return EHS开项跟踪集合
     */
    public List<TMtEhsopenitem> selectTMtEhsopenitemList(TMtEhsopenitem tMtEhsopenitem);

    /**
     * 新增EHS开项跟踪
     *
     * @param tMtEhsopenitem EHS开项跟踪
     * @return 结果
     */
    public int insertTMtEhsopenitem(TMtEhsopenitem tMtEhsopenitem);

    /**
     * 修改EHS开项跟踪
     *
     * @param tMtEhsopenitem EHS开项跟踪
     * @return 结果
     */
    public int updateTMtEhsopenitem(TMtEhsopenitem tMtEhsopenitem);

    /**
     * 删除EHS开项跟踪
     *
     * @param id EHS开项跟踪ID
     * @return 结果
     */
    public int deleteTMtEhsopenitemById(Long id);

    /**
     * 批量删除EHS开项跟踪
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTMtEhsopenitemByIds(Long[] ids);
}
